package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.KeyAreasMapper;
import com.ruoyi.system.domain.KeyAreas;
import com.ruoyi.system.service.IKeyAreasService;
import com.ruoyi.common.core.text.Convert;

/**
 * 重点区域Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-24
 */
@Service
public class KeyAreasServiceImpl implements IKeyAreasService
{
    @Autowired
    private KeyAreasMapper keyAreasMapper;

    /**
     * 查询重点区域
     *
     * @param id 重点区域主键
     * @return 重点区域
     */
    @Override
    public KeyAreas selectKeyAreasById(Long id)
    {
        return keyAreasMapper.selectKeyAreasById(id);
    }

    /**
     * 查询重点区域列表
     *
     * @param keyAreas 重点区域
     * @return 重点区域
     */
    @Override
    public List<KeyAreas> selectKeyAreasList(KeyAreas keyAreas)
    {
        return keyAreasMapper.selectKeyAreasList(keyAreas);
    }

    /**
     * 新增重点区域
     *
     * @param keyAreas 重点区域
     * @return 结果
     */
    @Override
    public int insertKeyAreas(KeyAreas keyAreas)
    {
        keyAreas.setParentId(1L);
        return keyAreasMapper.insertKeyAreas(keyAreas);
    }

    /**
     * 修改重点区域
     *
     * @param keyAreas 重点区域
     * @return 结果
     */
    @Override
    public int updateKeyAreas(KeyAreas keyAreas)
    {
        keyAreas.setParentId(1L);
        return keyAreasMapper.updateKeyAreas(keyAreas);
    }

    /**
     * 批量删除重点区域
     *
     * @param ids 需要删除的重点区域主键
     * @return 结果
     */
    @Override
    public int deleteKeyAreasByIds(String ids)
    {
        return keyAreasMapper.deleteKeyAreasByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除重点区域信息
     *
     * @param id 重点区域主键
     * @return 结果
     */
    @Override
    public int deleteKeyAreasById(Long id)
    {
        return keyAreasMapper.deleteKeyAreasById(id);
    }
}
